#!/bin/bash

#TRACE="--enable-trace-backends=syslog,simple"
TRACE=

git clean -fdx &>/dev/null
echo "Compile QEMU with no Xen support"
./configure --disable-xen --target-list=i386-softmmu &>/dev/null
make -j5 &>/dev/null
if [ $? -ne 0 ]; then
    echo "QEMU no Xen failed!"
else
    echo "QEMU no Xen succeeded!"
fi
git clean -fdx &>/dev/null

for i in 4.3 4.4
do
    echo "Compile QEMU with Xen $i"
    DIR="/local/xen-$i-testing"
    if test \! -d "$DIR" ; then
        echo "$DIR unavailable"
    fi
    ./configure --enable-xen --target-list=i386-softmmu --extra-cflags="-I$DIR/tools/include -I$DIR/tools/libxc -I$DIR/tools/xenstore"  --extra-ldflags="-L$DIR/tools/libxc -L$DIR/tools/xenstore" --disable-kvm &>/dev/null
    make -j5 &>/dev/null
    if [ $? -ne 0 ]; then
        echo "QEMU with $i Xen failed!"
    else
        echo "QEMU with $i Xen succeeded!"
    fi
    git clean -fdx &>/dev/null
done

for i in 4.5 4.6
do
    echo "Compile QEMU with Xen $i"
    DIR="/local/xen-$i-testing"
    if test \! -d "$DIR" ; then
        echo "$DIR unavailable"
    fi
    ./configure --enable-xen --target-list=i386-softmmu --extra-cflags="-I$DIR/tools/include -I$DIR/tools/libxc/include -I$DIR/tools/xenstore/include"  --extra-ldflags="-L$DIR/tools/libxc -L$DIR/tools/xenstore" --disable-kvm &>/dev/null
    make -j5 &>/dev/null
    if [ $? -ne 0 ]; then
        echo "QEMU with Xen $i failed!"
    else
        echo "QEMU with Xen $i succeeded!"
    fi
    git clean -fdx &>/dev/null
done

for i in 4.7
do
    echo "Compile QEMU with Xen $i"
    DIR="/local/xen-$i-testing"
    if test \! -d "$DIR" ; then
        echo "$DIR unavailable"
    fi
    ./configure --enable-xen --target-list=i386-softmmu \
    		--extra-cflags="-DXC_WANT_COMPAT_EVTCHN_API=1 \
    		-DXC_WANT_COMPAT_GNTTAB_API=1 \
    		-DXC_WANT_COMPAT_MAP_FOREIGN_API=1 \
    		-I$DIR/tools/include \
    		-I$DIR/tools/libs/toollog/include \
    		-I$DIR/tools/libs/evtchn/include \
    		-I$DIR/tools/libs/gnttab/include \
    		-I$DIR/tools/libs/foreignmemory/include \
    		-I$DIR/tools/libxc/include \
    		-I$DIR/tools/xenstore/include \
    		-I$DIR/tools/xenstore/compat/include" \
    		--extra-ldflags="-L$DIR/tools/libxc \
    		-L$DIR/tools/xenstore \
    		-L$DIR/tools/libs/evtchn \
    		-L$DIR/tools/libs/gnttab \
    		-L$DIR/tools/libs/foreignmemory \
    		-Wl,-rpath-link=$DIR/tools/libs/toollog \
    		-Wl,-rpath-link=$DIR/tools/libs/evtchn \
    		-Wl,-rpath-link=$DIR/tools/libs/gnttab \
    		-Wl,-rpath-link=$DIR/tools/libs/call \
    		-Wl,-rpath-link=$DIR/tools/libs/foreignmemory" \
            --disable-kvm &>/dev/null
    make -j5 &>/dev/null
    if [ $? -ne 0 ]; then
        echo "QEMU with Xen $i failed!"
    else
        echo "QEMU with Xen $i succeeded!"
    fi
    git clean -fdx &>/dev/null
done

for i in 4.8
do
    echo "Compile QEMU with Xen $i"
    DIR="/local/xen-$i-testing"
    if test \! -d "$DIR" ; then
        echo "$DIR unavailable"
    fi
    ./configure --enable-xen --target-list=i386-softmmu \
    		--extra-cflags="-I$DIR/tools/include \
    		-I$DIR/tools/libs/toollog/include \
    		-I$DIR/tools/libs/evtchn/include \
    		-I$DIR/tools/libs/gnttab/include \
    		-I$DIR/tools/libs/foreignmemory/include \
    		-I$DIR/tools/libxc/include \
    		-I$DIR/tools/xenstore/include \
    		-I$DIR/tools/xenstore/compat/include" \
    		--extra-ldflags="-L$DIR/tools/libxc \
    		-L$DIR/tools/xenstore \
    		-L$DIR/tools/libs/evtchn \
    		-L$DIR/tools/libs/gnttab \
    		-L$DIR/tools/libs/foreignmemory \
    		-Wl,-rpath-link=$DIR/tools/libs/toollog \
    		-Wl,-rpath-link=$DIR/tools/libs/evtchn \
    		-Wl,-rpath-link=$DIR/tools/libs/gnttab \
    		-Wl,-rpath-link=$DIR/tools/libs/call \
    		-Wl,-rpath-link=$DIR/tools/libs/foreignmemory" \
            --disable-kvm &>/dev/null
    make -j5 &>/dev/null
    if [ $? -ne 0 ]; then
        echo "QEMU with Xen $i failed!"
    else
        echo "QEMU with Xen $i succeeded!"
    fi
    git clean -fdx &>/dev/null
done

for i in 4.9
do
    echo "Compile QEMU with Xen $i (COMPAT_DEVICEMODEL)"
    DIR="/local/xen-$i-testing"
    if test \! -d "$DIR" ; then
        echo "$DIR unavailable"
    fi
    ./configure --enable-xen --target-list=i386-softmmu \
    		--extra-cflags="-DXC_WANT_COMPAT_DEVICEMODEL_API=1 \
            -I$DIR/tools/include \
    		-I$DIR/tools/libs/toollog/include \
    		-I$DIR/tools/libs/evtchn/include \
    		-I$DIR/tools/libs/gnttab/include \
    		-I$DIR/tools/libs/foreignmemory/include \
    		-I$DIR/tools/libxc/include \
    		-I$DIR/tools/xenstore/include \
    		-I$DIR/tools/xenstore/compat/include" \
    		--extra-ldflags="-L$DIR/tools/libxc \
    		-L$DIR/tools/xenstore \
    		-L$DIR/tools/libs/evtchn \
    		-L$DIR/tools/libs/gnttab \
    		-L$DIR/tools/libs/foreignmemory \
    		-L$DIR/tools/libs/devicemodel \
    		-Wl,-rpath-link=$DIR/tools/libs/toollog \
    		-Wl,-rpath-link=$DIR/tools/libs/evtchn \
    		-Wl,-rpath-link=$DIR/tools/libs/gnttab \
    		-Wl,-rpath-link=$DIR/tools/libs/call \
    		-Wl,-rpath-link=$DIR/tools/libs/foreignmemory \
    		-Wl,-rpath-link=$DIR/tools/libs/devicemodel" \
            --disable-kvm &>/dev/null
    make -j5 &>/dev/null
    if [ $? -ne 0 ]; then
        echo "QEMU with Xen $i failed!"
    else
        echo "QEMU with Xen $i succeeded!"
    fi
    git clean -fdx &>/dev/null
done

for i in 4.9
do
    echo "Compile QEMU with Xen $i"
    DIR="/local/xen-$i-testing"
    if test \! -d "$DIR" ; then
        echo "$DIR unavailable"
    fi
    ./configure --enable-xen --target-list=i386-softmmu \
    		--extra-cflags="-I$DIR/tools/include \
    		-I$DIR/tools/libs/toollog/include \
    		-I$DIR/tools/libs/evtchn/include \
    		-I$DIR/tools/libs/gnttab/include \
    		-I$DIR/tools/libs/foreignmemory/include \
    		-I$DIR/tools/libxc/include \
    		-I$DIR/tools/xenstore/include \
    		-I$DIR/tools/xenstore/compat/include" \
    		--extra-ldflags="-L$DIR/tools/libxc \
    		-L$DIR/tools/xenstore \
    		-L$DIR/tools/libs/evtchn \
    		-L$DIR/tools/libs/gnttab \
    		-L$DIR/tools/libs/foreignmemory \
    		-L$DIR/tools/libs/devicemodel \
    		-Wl,-rpath-link=$DIR/tools/libs/toollog \
    		-Wl,-rpath-link=$DIR/tools/libs/evtchn \
    		-Wl,-rpath-link=$DIR/tools/libs/gnttab \
    		-Wl,-rpath-link=$DIR/tools/libs/call \
    		-Wl,-rpath-link=$DIR/tools/libs/foreignmemory \
    		-Wl,-rpath-link=$DIR/tools/libs/devicemodel" \
            --disable-kvm &>/dev/null
    make -j5 &>/dev/null
    if [ $? -ne 0 ]; then
        echo "QEMU with Xen $i failed!"
    else
        echo "QEMU with Xen $i succeeded!"
    fi
    git clean -fdx &>/dev/null
done
